@@ -2,11 +2,11 @@ from delphai_utils.validator import validate as _validate, ValidationFailed
 from grpc import StatusCode
 
 
-def validate(descriptor, value, context):
+async def validate(descriptor, value, context):
   try:
     validated = _validate(descriptor)(value)
     return
   except ValidationFailed as ex:
     args = list(ex.args)
     errors = list(map(lambda err: err.replace('p.', ''), args))
-    context.abort(StatusCode.INVALID_ARGUMENT, ', '.join(errors))
\ No newline at end of file
+    await context.abort(StatusCode.INVALID_ARGUMENT, ', '.join(errors))
\ No newline at end of file
